@@ -107,7 +107,6 @@ Quick start: simplest usage
 
 """
 
-from __future__ import print_function
 
 __docformat__ = "restructuredtext en"
 
@@ -122,6 +121,7 @@ __all__ = (
 import os
 import sys
 import re
+from difflib import get_close_matches
 from os.path import exists, expanduser
 from optparse import OptionGroup
 from copy import copy
@@ -165,8 +165,7 @@ _ValueType = Union[List[str], Tuple[str, ...], str]
 
 
 def choice_validator(optdict: Dict[str, Any], name: str, value: str) -> str:
-    """validate and return a converted value for option of type 'choice'
-    """
+    """validate and return a converted value for option of type 'choice'"""
     if value not in optdict["choices"]:
         msg = "option %s: invalid value: %r, should be in %s"
         raise optik_ext.OptionValueError(msg % (name, value, optdict["choices"]))
@@ -174,8 +173,7 @@ def choice_validator(optdict: Dict[str, Any], name: str, value: str) -> str:
 
 
 def multiple_choice_validator(optdict: Dict[str, Any], name: str, value: _ValueType) -> _ValueType:
-    """validate and return a converted value for option of type 'choice'
-    """
+    """validate and return a converted value for option of type 'choice'"""
     choices = optdict["choices"]
     values = optik_ext.check_csv(None, name, value)
     for value in values:
@@ -186,22 +184,19 @@ def multiple_choice_validator(optdict: Dict[str, Any], name: str, value: _ValueT
 
 
 def csv_validator(optdict: Dict[str, Any], name: str, value: _ValueType) -> _ValueType:
-    """validate and return a converted value for option of type 'csv'
-    """
+    """validate and return a converted value for option of type 'csv'"""
     return optik_ext.check_csv(None, name, value)
 
 
 def yn_validator(optdict: Dict[str, Any], name: str, value: Union[bool, str]) -> bool:
-    """validate and return a converted value for option of type 'yn'
-    """
+    """validate and return a converted value for option of type 'yn'"""
     return optik_ext.check_yn(None, name, value)
 
 
 def named_validator(
     optdict: Dict[str, Any], name: str, value: Union[Dict[str, str], str]
 ) -> Dict[str, str]:
-    """validate and return a converted value for option of type 'named'
-    """
+    """validate and return a converted value for option of type 'named'"""
     return optik_ext.check_named(None, name, value)
 
 
@@ -260,7 +255,8 @@ def _call_validator(
     opttype: str, optdict: Dict[str, Any], option: str, value: Union[List[str], int, str]
 ) -> Union[List[str], int, str]:
     if opttype not in VALIDATORS:
-        raise Exception('Unsupported type "%s"' % opttype)
+        all_validators = "\n - ".join(sorted(VALIDATORS.keys()))
+        raise Exception(f'Unsupported type "{opttype}", supported types are:\n - {all_validators}')
     try:
         return VALIDATORS[opttype](optdict, option, value)
     except TypeError:
@@ -537,9 +533,7 @@ class OptionsManagerMixIn(object):
         # mypy: Need type annotation for 'option'
         # you can't type variable of a list comprehension, right?
         non_group_spec_options: List = [
-            option
-            for option in provider.options  # type: ignore
-            if "group" not in option[1]
+            option for option in provider.options if "group" not in option[1]  # type: ignore
         ]  # type: ignore
 
         groups = getattr(provider, "option_groups", ())
@@ -569,8 +563,7 @@ class OptionsManagerMixIn(object):
         options: Union[List[Tuple[str, Dict[str, Any]]], List[Tuple[str, Dict[str, str]]]],
         provider: "ConfigurationMixIn",
     ) -> None:
-        """add an option group including the listed options
-        """
+        """add an option group including the listed options"""
         assert options
         # add option group to the command line parser
         if group_name in self._mygroups:
@@ -665,6 +658,7 @@ class OptionsManagerMixIn(object):
         stream: Union[StringIO, TextIOWrapper] = None,
         skipsections: Tuple[()] = (),
         encoding: Optional[Any] = None,
+        header_message: Optional[str] = None,
     ) -> None:
         """write a configuration file according to the current configuration
         into the given stream or stdout
@@ -688,6 +682,14 @@ class OptionsManagerMixIn(object):
         stream = stream or sys.stdout
         encoding = _get_encoding(encoding, stream)
         printed = False
+        if header_message is not None:
+            # Make sure all the lines in header_message begin with '# '
+            # This is done by matching all the lines that do not start
+            # with '#' (possibly with whitespaces) and prefix them by '# '
+            exp = re.compile(r"^\s*(?=[^#])", re.MULTILINE)
+            commented_header = exp.sub("# ", header_message)
+            print(commented_header, file=stream)
+
         for section in sections:
             if printed:
                 print("\n", file=stream)
@@ -794,8 +796,7 @@ class OptionsManagerMixIn(object):
                     continue
 
     def load_configuration(self, **kwargs: Any) -> None:
-        """override configuration according to given parameters
-        """
+        """override configuration according to given parameters"""
         for opt, opt_value in kwargs.items():
             opt = opt.replace("_", "-")
             provider = self._all_options[opt]
@@ -828,7 +829,7 @@ class OptionsManagerMixIn(object):
     # help methods ############################################################
 
     def add_help_section(self, title: str, description: str, level: int = 0) -> None:
-        """add a dummy option section for help purpose """
+        """add a dummy option section for help purpose"""
         group = optik_ext.OptionGroup(
             self.cmdline_parser, title=title.capitalize(), description=description
         )
@@ -859,7 +860,7 @@ class OptionsManagerMixIn(object):
             optik_ext.HelpFormatter.expand_default = self.__expand_default_backup  # type: ignore
 
     def help(self, level: int = 0) -> str:
-        """return the usage string for available options """
+        """return the usage string for available options"""
         # mypy: "HelpFormatter" has no attribute "output_level"
         # set in optik_ext
         self.cmdline_parser.formatter.output_level = level  # type: ignore
@@ -935,8 +936,7 @@ class OptionsProviderMixIn(object):
         return default
 
     def option_attrname(self, opt, optdict=None):
-        """get the config attribute corresponding to opt
-        """
+        """get the config attribute corresponding to opt"""
         if optdict is None:
             optdict = self.get_option_def(opt)
         return optdict.get("dest", opt.replace("-", "_"))
@@ -950,8 +950,7 @@ class OptionsProviderMixIn(object):
         return getattr(self.config, self.option_attrname(opt), None)
 
     def set_option(self, opt, value, action=None, optdict=None):
-        """method called to set an option (registered in the options list)
-        """
+        """method called to set an option (registered in the options list)"""
         if optdict is None:
             optdict = self.get_option_def(opt)
         if value is not None:
@@ -1018,7 +1017,20 @@ class OptionsProviderMixIn(object):
                 return option[1]
         # mypy: Argument 2 to "OptionError" has incompatible type "str"; expected "Option"
         # seems to be working?
-        raise OptionError("no such option %s in section %r" % (opt, self.name), opt)  # type: ignore
+        similar_options = get_close_matches(opt, (str(x[0]) for x in self.options), n=10)
+        if similar_options:
+            raise OptionError(
+                "no such option %s in section %r.\n\nOptions with a similar name are:\n * %s"
+                % (opt, self.name, "\n * ".join(similar_options)),
+                opt,
+            )  # type: ignore
+        else:
+            raise OptionError(
+                "no such option %s in section %r.\n\nNo option with a similar name, "
+                "all available options:\n * %s"
+                % (opt, self.name, "\n * ".join(str(x[0]) for x in self.options)),
+                opt,
+            )  # type: ignore
 
     def all_options(self):
         """return an iterator on available options for this provider
