@@ -16,7 +16,6 @@
 # You should have received a copy of the GNU Lesser General Public License along
 # with logilab-common.  If not, see <http://www.gnu.org/licenses/>.
 """Date manipulation helper functions."""
-from __future__ import division
 
 __docformat__ = "restructuredtext en"
 
@@ -27,6 +26,9 @@ from locale import getlocale, LC_TIME
 from datetime import date, time, datetime, timedelta
 from time import strptime as time_strptime
 from calendar import monthrange, timegm
+from typing import Union, List, Any, Optional, Generator
+
+from logilab.common.deprecation import callable_deprecated
 
 try:
     from mx.DateTime import RelativeDateTime, Date, DateTimeType
@@ -40,63 +42,59 @@ else:
 #       as we have in lgc.db ?
 
 FRENCH_FIXED_HOLIDAYS = {
-    'jour_an': '%s-01-01',
-    'fete_travail': '%s-05-01',
-    'armistice1945': '%s-05-08',
-    'fete_nat': '%s-07-14',
-    'assomption': '%s-08-15',
-    'toussaint': '%s-11-01',
-    'armistice1918': '%s-11-11',
-    'noel': '%s-12-25',
-    }
+    "jour_an": "%s-01-01",
+    "fete_travail": "%s-05-01",
+    "armistice1945": "%s-05-08",
+    "fete_nat": "%s-07-14",
+    "assomption": "%s-08-15",
+    "toussaint": "%s-11-01",
+    "armistice1918": "%s-11-11",
+    "noel": "%s-12-25",
+}
 
 FRENCH_MOBILE_HOLIDAYS = {
-    'paques2004': '2004-04-12',
-    'ascension2004': '2004-05-20',
-    'pentecote2004': '2004-05-31',
-
-    'paques2005': '2005-03-28',
-    'ascension2005': '2005-05-05',
-    'pentecote2005': '2005-05-16',
-
-    'paques2006': '2006-04-17',
-    'ascension2006': '2006-05-25',
-    'pentecote2006': '2006-06-05',
-
-    'paques2007': '2007-04-09',
-    'ascension2007': '2007-05-17',
-    'pentecote2007': '2007-05-28',
-
-    'paques2008': '2008-03-24',
-    'ascension2008': '2008-05-01',
-    'pentecote2008': '2008-05-12',
-
-    'paques2009': '2009-04-13',
-    'ascension2009': '2009-05-21',
-    'pentecote2009': '2009-06-01',
-
-    'paques2010': '2010-04-05',
-    'ascension2010': '2010-05-13',
-    'pentecote2010': '2010-05-24',
-
-    'paques2011': '2011-04-25',
-    'ascension2011': '2011-06-02',
-    'pentecote2011': '2011-06-13',
-
-    'paques2012': '2012-04-09',
-    'ascension2012': '2012-05-17',
-    'pentecote2012': '2012-05-28',
-    }
+    "paques2004": "2004-04-12",
+    "ascension2004": "2004-05-20",
+    "pentecote2004": "2004-05-31",
+    "paques2005": "2005-03-28",
+    "ascension2005": "2005-05-05",
+    "pentecote2005": "2005-05-16",
+    "paques2006": "2006-04-17",
+    "ascension2006": "2006-05-25",
+    "pentecote2006": "2006-06-05",
+    "paques2007": "2007-04-09",
+    "ascension2007": "2007-05-17",
+    "pentecote2007": "2007-05-28",
+    "paques2008": "2008-03-24",
+    "ascension2008": "2008-05-01",
+    "pentecote2008": "2008-05-12",
+    "paques2009": "2009-04-13",
+    "ascension2009": "2009-05-21",
+    "pentecote2009": "2009-06-01",
+    "paques2010": "2010-04-05",
+    "ascension2010": "2010-05-13",
+    "pentecote2010": "2010-05-24",
+    "paques2011": "2011-04-25",
+    "ascension2011": "2011-06-02",
+    "pentecote2011": "2011-06-13",
+    "paques2012": "2012-04-09",
+    "ascension2012": "2012-05-17",
+    "pentecote2012": "2012-05-28",
+}
 
 # XXX this implementation cries for multimethod dispatching
 
-def get_step(dateobj, nbdays=1):
+
+def get_step(dateobj: Union[date, datetime], nbdays: int = 1) -> timedelta:
     # assume date is either a python datetime or a mx.DateTime object
     if isinstance(dateobj, date):
         return ONEDAY * nbdays
-    return nbdays # mx.DateTime is ok with integers
+    return nbdays  # mx.DateTime is ok with integers
 
-def datefactory(year, month, day, sampledate):
+
+def datefactory(
+    year: int, month: int, day: int, sampledate: Union[date, datetime]
+) -> Union[date, datetime]:
     # assume date is either a python datetime or a mx.DateTime object
     if isinstance(sampledate, datetime):
         return datetime(year, month, day)
@@ -104,20 +102,26 @@ def datefactory(year, month, day, sampledate):
         return date(year, month, day)
     return Date(year, month, day)
 
-def weekday(dateobj):
+
+def weekday(dateobj: Union[date, datetime]) -> int:
     # assume date is either a python datetime or a mx.DateTime object
     if isinstance(dateobj, date):
         return dateobj.weekday()
     return dateobj.day_of_week
 
-def str2date(datestr, sampledate):
+
+def str2date(datestr: str, sampledate: Union[date, datetime]) -> Union[date, datetime]:
     # NOTE: datetime.strptime is not an option until we drop py2.4 compat
-    year, month, day = [int(chunk) for chunk in datestr.split('-')]
+    year, month, day = [int(chunk) for chunk in datestr.split("-")]
     return datefactory(year, month, day, sampledate)
 
-def days_between(start, end):
+
+def days_between(start: Union[date, datetime], end: Union[date, datetime]) -> int:
     if isinstance(start, date):
-        delta = end - start
+        # mypy: No overload variant of "__sub__" of "datetime" matches argument type "date"
+        # we ensure that end is a date
+        assert isinstance(end, date)
+        delta = end - start  # type: ignore
         # datetime.timedelta.days is always an integer (floored)
         if delta.seconds:
             return delta.days + 1
@@ -125,33 +129,36 @@ def days_between(start, end):
     else:
         return int(math.ceil((end - start).days))
 
-def get_national_holidays(begin, end):
+
+def get_national_holidays(
+    begin: Union[date, datetime], end: Union[date, datetime]
+) -> Union[List[date], List[datetime]]:
     """return french national days off between begin and end"""
     begin = datefactory(begin.year, begin.month, begin.day, begin)
     end = datefactory(end.year, end.month, end.day, end)
-    holidays = [str2date(datestr, begin)
-                for datestr in FRENCH_MOBILE_HOLIDAYS.values()]
-    for year in range(begin.year, end.year+1):
+    holidays = [str2date(datestr, begin) for datestr in FRENCH_MOBILE_HOLIDAYS.values()]
+    for year in range(begin.year, end.year + 1):
         for datestr in FRENCH_FIXED_HOLIDAYS.values():
             date = str2date(datestr % year, begin)
             if date not in holidays:
                 holidays.append(date)
     return [day for day in holidays if begin <= day < end]
 
-def add_days_worked(start, days):
+
+def add_days_worked(start: date, days: int) -> date:
     """adds date but try to only take days worked into account"""
     step = get_step(start)
     weeks, plus = divmod(days, 5)
     end = start + ((weeks * 7) + plus) * step
-    if weekday(end) >= 5: # saturday or sunday
-        end += (2 * step)
-    end += len([x for x in get_national_holidays(start, end + step)
-                if weekday(x) < 5]) * step
-    if weekday(end) >= 5: # saturday or sunday
-        end += (2 * step)
+    if weekday(end) >= 5:  # saturday or sunday
+        end += 2 * step
+    end += len([x for x in get_national_holidays(start, end + step) if weekday(x) < 5]) * step
+    if weekday(end) >= 5:  # saturday or sunday
+        end += 2 * step
     return end
 
-def nb_open_days(start, end):
+
+def nb_open_days(start: Union[date, datetime], end: Union[date, datetime]) -> int:
     assert start <= end
     step = get_step(start)
     days = days_between(start, end)
@@ -161,14 +168,18 @@ def nb_open_days(start, end):
     elif weekday(end) == 6:
         plus -= 1
     open_days = weeks * 5 + plus
-    nb_week_holidays = len([x for x in get_national_holidays(start, end+step)
-                            if weekday(x) < 5 and x < end])
+    nb_week_holidays = len(
+        [x for x in get_national_holidays(start, end + step) if weekday(x) < 5 and x < end]
+    )
     open_days -= nb_week_holidays
     if open_days < 0:
         return 0
     return open_days
 
-def date_range(begin, end, incday=None, incmonth=None):
+
+def date_range(
+    begin: date, end: date, incday: Optional[Any] = None, incmonth: Optional[bool] = None
+) -> Generator[date, Any, None]:
     """yields each date between begin and end
 
     :param begin: the start date
@@ -193,31 +204,30 @@ def date_range(begin, end, incday=None, incmonth=None):
     else:
         incr = get_step(begin, incday or 1)
         while begin < end:
-           yield begin
-           begin += incr
+            yield begin
+            begin += incr
+
 
 # makes py datetime usable #####################################################
 
-ONEDAY = timedelta(days=1)
-ONEWEEK = timedelta(days=7)
+ONEDAY: timedelta = timedelta(days=1)
+ONEWEEK: timedelta = timedelta(days=7)
 
-try:
-    strptime = datetime.strptime
-except AttributeError: # py < 2.5
-    from time import strptime as time_strptime
-    def strptime(value, format):
-        return datetime(*time_strptime(value, format)[:6])
+strptime = callable_deprecated("Use strptime from datetime.datetime instead")(datetime.strptime)
 
-def strptime_time(value, format='%H:%M'):
+
+def strptime_time(value, format="%H:%M"):
     return time(*time_strptime(value, format)[3:6])
 
-def todate(somedate):
+
+def todate(somedate: date) -> date:
     """return a date from a date (leaving unchanged) or a datetime"""
     if isinstance(somedate, datetime):
         return date(somedate.year, somedate.month, somedate.day)
     assert isinstance(somedate, (date, DateTimeType)), repr(somedate)
     return somedate
 
+
 def totime(somedate):
     """return a time from a time (leaving unchanged), date or datetime"""
     # XXX mx compat
@@ -226,6 +236,7 @@ def totime(somedate):
     assert isinstance(somedate, (time)), repr(somedate)
     return somedate
 
+
 def todatetime(somedate):
     """return a date from a date (leaving unchanged) or a datetime"""
     # take care, datetime is a subclass of date
@@ -234,10 +245,12 @@ def todatetime(somedate):
     assert isinstance(somedate, (date, DateTimeType)), repr(somedate)
     return datetime(somedate.year, somedate.month, somedate.day)
 
-def datetime2ticks(somedate):
-    return timegm(somedate.timetuple()) * 1000 + int(getattr(somedate, 'microsecond', 0) / 1000)
 
-def ticks2datetime(ticks):
+def datetime2ticks(somedate: Union[date, datetime]) -> int:
+    return timegm(somedate.timetuple()) * 1000 + int(getattr(somedate, "microsecond", 0) / 1000)
+
+
+def ticks2datetime(ticks: int) -> datetime:
     miliseconds, microseconds = divmod(ticks, 1000)
     try:
         return datetime.fromtimestamp(miliseconds)
@@ -250,9 +263,11 @@ def ticks2datetime(ticks):
         except (ValueError, OverflowError):
             raise
 
-def days_in_month(somedate):
+
+def days_in_month(somedate: date) -> int:
     return monthrange(somedate.year, somedate.month)[1]
 
+
 def days_in_year(somedate):
     feb = date(somedate.year, 2, 1)
     if days_in_month(feb) == 29:
@@ -260,25 +275,30 @@ def days_in_year(somedate):
     else:
         return 365
 
+
 def previous_month(somedate, nbmonth=1):
     while nbmonth:
         somedate = first_day(somedate) - ONEDAY
         nbmonth -= 1
     return somedate
 
-def next_month(somedate, nbmonth=1):
+
+def next_month(somedate: date, nbmonth: int = 1) -> date:
     while nbmonth:
         somedate = last_day(somedate) + ONEDAY
         nbmonth -= 1
     return somedate
 
+
 def first_day(somedate):
     return date(somedate.year, somedate.month, 1)
 
-def last_day(somedate):
+
+def last_day(somedate: date) -> date:
     return date(somedate.year, somedate.month, days_in_month(somedate))
 
-def ustrftime(somedate, fmt='%Y-%m-%d'):
+
+def ustrftime(somedate: datetime, fmt: str = "%Y-%m-%d") -> str:
     """like strftime, but returns a unicode string instead of an encoded
     string which may be problematic with localized date.
     """
@@ -288,8 +308,8 @@ def ustrftime(somedate, fmt='%Y-%m-%d'):
     else:
         try:
             if sys.version_info < (3, 0):
-                encoding = getlocale(LC_TIME)[1] or 'ascii'
-                return unicode(somedate.strftime(str(fmt)), encoding)
+                encoding = getlocale(LC_TIME)[1] or "ascii"
+                return str(somedate.strftime(str(fmt)), encoding)
             else:
                 return somedate.strftime(fmt)
         except ValueError:
@@ -298,36 +318,40 @@ def ustrftime(somedate, fmt='%Y-%m-%d'):
             # datetime is not happy with dates before 1900
             # we try to work around this, assuming a simple
             # format string
-            fields = {'Y': somedate.year,
-                      'm': somedate.month,
-                      'd': somedate.day,
-                      }
+            fields = {
+                "Y": somedate.year,
+                "m": somedate.month,
+                "d": somedate.day,
+            }
             if isinstance(somedate, datetime):
-                fields.update({'H': somedate.hour,
-                               'M': somedate.minute,
-                               'S': somedate.second})
-            fmt = re.sub('%([YmdHMS])', r'%(\1)02d', fmt)
-            return unicode(fmt) % fields
+                fields.update({"H": somedate.hour, "M": somedate.minute, "S": somedate.second})
+            fmt = re.sub("%([YmdHMS])", r"%(\1)02d", fmt)
+            return str(fmt) % fields
 
-def utcdatetime(dt):
+
+def utcdatetime(dt: datetime) -> datetime:
     if dt.tzinfo is None:
         return dt
-    return (dt.replace(tzinfo=None) - dt.utcoffset())
+    # mypy: No overload variant of "__sub__" of "datetime" matches argument type "None"
+    return dt.replace(tzinfo=None) - dt.utcoffset()  # type: ignore
+
 
 def utctime(dt):
     if dt.tzinfo is None:
         return dt
     return (dt + dt.utcoffset() + dt.dst()).replace(tzinfo=None)
 
+
 def datetime_to_seconds(date):
-    """return the number of seconds since the begining of the day for that date
-    """
-    return date.second+60*date.minute + 3600*date.hour
+    """return the number of seconds since the begining of the day for that date"""
+    return date.second + 60 * date.minute + 3600 * date.hour
+
 
 def timedelta_to_days(delta):
     """return the time delta as a number of seconds"""
-    return delta.days + delta.seconds / (3600*24)
+    return delta.days + delta.seconds / (3600 * 24)
+
 
 def timedelta_to_seconds(delta):
     """return the time delta as a fraction of days"""
-    return delta.days*(3600*24) + delta.seconds
+    return delta.days * (3600 * 24) + delta.seconds
