@@ -34,7 +34,7 @@ else:
     import importlib_metadata
 
 
-def get_real__name__(some_callable: Callable) -> str:
+def _unstack_all_deprecation_decorators(function):
     """
     This is another super edge magic case which is needed because we uses
     lazy_wraps because of logilab.common.modutils.LazyObject and because
@@ -44,12 +44,18 @@ def get_real__name__(some_callable: Callable) -> str:
     Therefor, to get the real callable name when several lazy_wrapped
     decorator are used we need to travers the __wrapped__ attributes chain.
     """
+    while hasattr(function, "__wrapped__"):
+        function = function.__wrapped__
 
-    targeted_callable = some_callable
-    while hasattr(targeted_callable, "__wrapped__"):
-        targeted_callable = targeted_callable.__wrapped__  # type: ignore
+    return function
 
-    return targeted_callable.__name__
+
+def get_real__name__(some_callable: Callable) -> str:
+    return _unstack_all_deprecation_decorators(some_callable).__name__
+
+
+def get_real__module__(some_callable: Callable) -> str:
+    return _unstack_all_deprecation_decorators(some_callable).__module__
 
 
 def lazy_wraps(wrapped: Callable) -> Callable:
@@ -154,7 +160,11 @@ def _get_module_name(number: int = 1) -> str:
 _cached_path_to_package: Optional[Dict[str, Optional[str]]] = None
 
 
-def _get_package_name(file_path: str) -> Optional[str]:
+def _get_package_name(python_object) -> Optional[str]:
+    # only do this work if we are in a pytest session
+    if "COLLECT_DEPRECATION_WARNINGS_PACKAGE_NAME" not in os.environ:
+        return None
+
     global _cached_path_to_package
 
     if _cached_path_to_package is None:
@@ -163,11 +173,24 @@ def _get_package_name(file_path: str) -> Optional[str]:
         # instantiate abstract class 'Distribution' with abstract attributes
         # 'locate_file' and 'read_text'
         for distribution in importlib_metadata.Distribution().discover():  # type: ignore
-            if distribution.files:
+            # sometime distribution has a "name" attribute, sometime not
+            if distribution.files and hasattr(distribution, "name"):
                 for file in distribution.files:
                     _cached_path_to_package[str(distribution.locate_file(file))] = distribution.name
+                continue
 
-    return _cached_path_to_package.get(file_path)
+            if distribution.files and "name" in distribution.metadata:
+                for file in distribution.files:
+                    _cached_path_to_package[
+                        str(distribution.locate_file(file))
+                    ] = distribution.metadata["name"]
+
+    try:
+        return _cached_path_to_package.get(
+            inspect.getfile(_unstack_all_deprecation_decorators(python_object))
+        )
+    except TypeError:
+        return None
 
 
 def send_warning(
@@ -313,11 +336,11 @@ def callable_renamed(
                 "old_name": old_name,
                 "new_name": get_real__name__(new_function),
                 "version": version,
-                "package": _get_package_name(inspect.getfile(new_function)),
+                "package": _get_package_name(new_function),
             },
             stacklevel=3,
             version=version,
-            module_name=new_function.__module__,
+            module_name=get_real__module__(new_function),
         )
         return new_function(*args, **kwargs)
 
@@ -354,11 +377,11 @@ def argument_removed(old_argument_name: str, version: Optional[str] = None) -> C
                         "kind": DeprecationWarningKind.ARGUMENT,
                         "name": old_argument_name,
                         "version": version,
-                        "package": _get_package_name(inspect.getfile(func)),
+                        "package": _get_package_name(func),
                     },
                     stacklevel=3,
                     version=version,
-                    module_name=func.__module__,
+                    module_name=get_real__module__(func),
                 )
                 del kwargs[old_argument_name]
 
@@ -391,11 +414,11 @@ def callable_deprecated(
                 deprecation_class_kwargs={
                     "kind": DeprecationWarningKind.CALLABLE,
                     "version": version,
-                    "package": _get_package_name(inspect.getfile(func)),
+                    "package": _get_package_name(func),
                 },
                 version=version,
                 stacklevel=stacklevel + 1,
-                module_name=func.__module__,
+                module_name=get_real__module__(func),
             )
             return func(*args, **kwargs)
 
@@ -422,7 +445,7 @@ def _generate_class_deprecated():
 
         def __call__(cls, *args, **kwargs):
             message = getattr(cls, "__deprecation_warning__", "%(cls)s is deprecated") % {
-                "cls": cls.__name__
+                "cls": get_real__name__(cls)
             }
             send_warning(
                 message,
@@ -434,7 +457,7 @@ def _generate_class_deprecated():
                     "__deprecation_warning_class_kwargs__",
                     {
                         "kind": DeprecationWarningKind.CLASS,
-                        "package": _get_package_name(inspect.getfile(cls)),
+                        "package": _get_package_name(cls),
                         "version": getattr(cls, "__deprecation_warning_version__", None),
                     },
                 ),
@@ -477,8 +500,8 @@ def attribute_renamed(old_name: str, new_name: str, version: Optional[str] = Non
 
     def _class_wrap(klass: type) -> type:
         reason = (
-            f"{klass.__name__}.{old_name} has been renamed and is deprecated, use "
-            f"{klass.__name__}.{new_name} instead"
+            f"{get_real__name__(klass)}.{old_name} has been renamed and is deprecated, use "
+            f"{get_real__name__(klass)}.{new_name} instead"
         )
 
         def _get_old(self) -> Any:
@@ -490,11 +513,11 @@ def attribute_renamed(old_name: str, new_name: str, version: Optional[str] = Non
                     "old_name": old_name,
                     "new_name": new_name,
                     "version": version,
-                    "package": _get_package_name(inspect.getfile(self.__class__)),
+                    "package": _get_package_name(klass),
                 },
                 stacklevel=3,
                 version=version,
-                module_name=klass.__module__,
+                module_name=get_real__module__(klass),
             )
             return getattr(self, new_name)
 
@@ -507,11 +530,11 @@ def attribute_renamed(old_name: str, new_name: str, version: Optional[str] = Non
                     "old_name": old_name,
                     "new_name": new_name,
                     "version": version,
-                    "package": _get_package_name(inspect.getfile(self.__class__)),
+                    "package": _get_package_name(klass),
                 },
                 stacklevel=3,
                 version=version,
-                module_name=klass.__module__,
+                module_name=get_real__module__(klass),
             )
             setattr(self, new_name, value)
 
@@ -524,11 +547,11 @@ def attribute_renamed(old_name: str, new_name: str, version: Optional[str] = Non
                     "old_name": old_name,
                     "new_name": new_name,
                     "version": version,
-                    "package": _get_package_name(inspect.getfile(self.__class__)),
+                    "package": _get_package_name(klass),
                 },
                 stacklevel=3,
                 version=version,
-                module_name=klass.__module__,
+                module_name=get_real__module__(klass),
             )
             delattr(self, new_name)
 
@@ -573,11 +596,11 @@ def argument_renamed(old_name: str, new_name: str, version: Optional[str] = None
                         "old_name": old_name,
                         "new_name": new_name,
                         "version": version,
-                        "package": _get_package_name(inspect.getfile(func)),
+                        "package": _get_package_name(func),
                     },
                     stacklevel=3,
                     version=version,
-                    module_name=func.__module__,
+                    module_name=get_real__module__(func),
                 )
                 kwargs[new_name] = kwargs[old_name]
                 del kwargs[old_name]
@@ -634,7 +657,7 @@ def callable_moved(
                 "old_module": old_module,
                 "new_module": module_name,
                 "version": version,
-                "package": _get_package_name(inspect.getfile(getattr(m, object_name))),
+                "package": _get_package_name(getattr(m, object_name)),
             },
             version=version,
             stacklevel=stacklevel + 1,
@@ -671,7 +694,7 @@ def class_renamed(
     """
     class_dict: Dict[str, Any] = {}
     if message is None:
-        message = "%s is deprecated, use %s instead" % (old_name, new_class.__name__)
+        message = "%s is deprecated, use %s instead" % (old_name, get_real__name__(new_class))
 
     class_dict["__deprecation_warning__"] = message
     class_dict["__deprecation_warning_class__"] = deprecated_warning_class
@@ -679,9 +702,9 @@ def class_renamed(
         class_dict["__deprecation_warning_class_kwargs__"] = {
             "kind": DeprecationWarningKind.CLASS,
             "old_name": old_name,
-            "new_name": new_class.__name__,
+            "new_name": get_real__name__(new_class),
             "version": version,
-            "package": _get_package_name(inspect.getfile(new_class)),
+            "package": _get_package_name(new_class),
         }
     else:
         class_dict["__deprecation_warning_class_kwargs__"] = deprecated_warning_kwargs
@@ -702,7 +725,7 @@ def class_renamed(
             def __init__(self, *args, **kwargs):
                 msg = class_dict.get(
                     "__deprecation_warning__",
-                    f"{old_name} is deprecated, use {new_class.__name__} instead",
+                    f"{old_name} is deprecated, use {get_real__name__(new_class)} instead",
                 )
                 send_warning(
                     msg,
@@ -710,9 +733,9 @@ def class_renamed(
                     deprecation_class_kwargs={
                         "kind": DeprecationWarningKind.CLASS,
                         "old_name": old_name,
-                        "new_name": new_class.__name__,
+                        "new_name": get_real__name__(new_class),
                         "version": version,
-                        "package": _get_package_name(inspect.getfile(new_class)),
+                        "package": _get_package_name(new_class),
                     },
                     stacklevel=class_dict.get("__deprecation_warning_stacklevel__", 3),
                     version=class_dict.get("__deprecation_warning_version__", None),
@@ -732,7 +755,7 @@ def class_moved(
     another module
     """
     if old_name is None:
-        old_name = new_class.__name__
+        old_name = get_real__name__(new_class)
 
     old_module = _get_module_name(1)
 
@@ -740,8 +763,8 @@ def class_moved(
         message = "class %s.%s is now available as %s.%s" % (
             old_module,
             old_name,
-            new_class.__module__,
-            new_class.__name__,
+            get_real__module__(new_class),
+            get_real__name__(new_class),
         )
 
     module_name = _get_module_name(1)
@@ -756,10 +779,10 @@ def class_moved(
         deprecated_warning_kwargs={
             "kind": DeprecationWarningKind.CLASS,
             "old_module": old_module,
-            "new_module": new_class.__module__,
+            "new_module": get_real__module__(new_class),
             "old_name": old_name,
-            "new_name": new_class.__name__,
+            "new_name": get_real__name__(new_class),
             "version": version,
-            "package": _get_package_name(inspect.getfile(new_class)),
+            "package": _get_package_name(new_class),
         },
     )
