@@ -72,7 +72,7 @@ class ProcInfo(Node):
         """return the memory usage of the process in Ko"""
         try:
             return int(self.status()[VSIZE])
-        except IOError:
+        except OSError:
             return 0
 
     def lineage_memory_usage(self):
