@@ -76,8 +76,6 @@ Exceptions
 .. autoclass:: NoSelectableObject
 """
 
-from __future__ import print_function
-
 
 __docformat__ = "restructuredtext en"
 
@@ -93,7 +91,12 @@ from logging import getLogger
 from warnings import warn
 from typing import List, Tuple, Any, Iterable, Callable
 from types import ModuleType
-from typing_extensions import TypedDict
+
+if sys.version_info >= (3, 8):
+    from typing import TypedDict
+
+    # TypedDict is also available in typing_extension > 3.7.4,
+    # but this package is not available on debian buster.
 
 from logilab.common.modutils import modpath_from_file
 from logilab.common.logging_ext import set_log_methods
@@ -464,7 +467,7 @@ class RegistrableInstance(RegistrableObject):
         obj = super(RegistrableInstance, cls).__new__(cls)
         if module is None:
             warn(
-                "instantiate {0} with " "__module__=__name__".format(cls.__name__),
+                "instantiate {} with " "__module__=__name__".format(cls.__name__),
                 DeprecationWarning,
             )
             # XXX subclass must no override __new__
@@ -478,19 +481,22 @@ class RegistrableInstance(RegistrableObject):
         super(RegistrableInstance, self).__init__()
 
 
-SelectBestReport = TypedDict(
-    "SelectBestReport",
-    {
-        "all_objects": List,
-        "end_score": int,
-        "winners": List,
-        "winner": Optional[Any],
-        "self": "Registry",
-        "args": List,
-        "kwargs": Dict,
-        "registry": "Registry",
-    },
-)
+if sys.version_info >= (3, 8):
+    SelectBestReport = TypedDict(
+        "SelectBestReport",
+        {
+            "all_objects": List,
+            "end_score": int,
+            "winners": List,
+            "winner": Optional[Any],
+            "self": "Registry",
+            "args": List,
+            "kwargs": Dict,
+            "registry": "Registry",
+        },
+    )
+else:
+    SelectBestReport = Dict[str, Union[List, int, Optional[Any], "Registry", Dict]]
 
 
 class Registry(dict):
@@ -1050,7 +1056,7 @@ class RegistryStore(dict):
             reg.initialization_completed()
 
     def _mdate(self, filepath: str) -> Optional[int]:
-        """ return the modification date of a file path """
+        """return the modification date of a file path"""
         try:
             return stat(filepath)[-2]
         except OSError:
@@ -1080,7 +1086,7 @@ class RegistryStore(dict):
         return False
 
     def load_file(self, filepath: str, modname: str) -> None:
-        """ load registrable objects (if any) from a python file """
+        """load registrable objects (if any) from a python file"""
         if modname in self._loadedmods:
             return
         self._loadedmods[modname] = {}
