@@ -17,7 +17,6 @@
 # with logilab-common.  If not, see <http://www.gnu.org/licenses/>.
 """Table management module."""
 
-from __future__ import print_function
 from types import CodeType
 from typing import Any, List, Optional, Tuple, Union, Dict, Iterator
 from _io import StringIO
@@ -85,36 +84,31 @@ class Table(object):
 
     # Rows / Columns creation #################################################
     def create_rows(self, row_names: List[str]) -> None:
-        """Appends row_names to the list of existing rows
-        """
+        """Appends row_names to the list of existing rows"""
         self.row_names.extend(row_names)
         for row_name in row_names:
             self.data.append([self.default_value] * len(self.col_names))
 
     def create_columns(self, col_names: List[str]) -> None:
-        """Appends col_names to the list of existing columns
-        """
+        """Appends col_names to the list of existing columns"""
         for col_name in col_names:
             self.create_column(col_name)
 
     def create_row(self, row_name: str = None) -> None:
-        """Creates a rowname to the row_names list
-        """
+        """Creates a rowname to the row_names list"""
         row_name = row_name or self._next_row_name()
         self.row_names.append(row_name)
         self.data.append([self.default_value] * len(self.col_names))
 
     def create_column(self, col_name: str) -> None:
-        """Creates a colname to the col_names list
-        """
+        """Creates a colname to the col_names list"""
         self.col_names.append(col_name)
         for row in self.data:
             row.append(self.default_value)
 
     # Sort by column ##########################################################
     def sort_by_column_id(self, col_id: str, method: str = "asc") -> None:
-        """Sorts the table (in-place) according to data stored in col_id
-        """
+        """Sorts the table (in-place) according to data stored in col_id"""
         try:
             col_index = self.col_names.index(col_id)
             self.sort_by_column_index(col_index, method)
@@ -179,8 +173,7 @@ class Table(object):
 
     # The 'setter' part #######################################################
     def set_cell(self, row_index: int, col_index: int, data: int) -> None:
-        """sets value of cell 'row_indew', 'col_index' to data
-        """
+        """sets value of cell 'row_indew', 'col_index' to data"""
         self.data[row_index][col_index] = data
 
     def set_cell_by_ids(self, row_id: str, col_id: str, data: Union[int, str]) -> None:
@@ -336,8 +329,7 @@ class Table(object):
     # The 'getter' part #######################################################
 
     def get_shape(self) -> Tuple[int, int]:
-        """Returns a tuple which represents the table's shape
-        """
+        """Returns a tuple which represents the table's shape"""
         return len(self.row_names), len(self.col_names)
 
     shape = property(get_shape)
@@ -412,8 +404,7 @@ class Table(object):
                 return tab.data[0][0]
 
     def get_cell_by_ids(self, row_id, col_id):
-        """Returns the element at [row_id][col_id]
-        """
+        """Returns the element at [row_id][col_id]"""
         try:
             row_index = self.row_names.index(row_id)
         except ValueError:
@@ -426,8 +417,7 @@ class Table(object):
         return self.data[row_index][col_index]
 
     def get_row_by_id(self, row_id):
-        """Returns the 'row_id' row
-        """
+        """Returns the 'row_id' row"""
         try:
             row_index = self.row_names.index(row_id)
         except ValueError:
@@ -435,8 +425,7 @@ class Table(object):
         return self.data[row_index]
 
     def get_column_by_id(self, col_id, distinct=False):
-        """Returns the 'col_id' col
-        """
+        """Returns the 'col_id' col"""
         try:
             col_index = self.col_names.index(col_id)
         except ValueError:
@@ -444,8 +433,7 @@ class Table(object):
         return self.get_column(col_index, distinct)
 
     def get_columns(self) -> List[List[int]]:
-        """Returns all the columns in the table
-        """
+        """Returns all the columns in the table"""
         return [self[:, index] for index in range(len(self.col_names))]
 
     def get_column(self, col_index, distinct=False):
@@ -456,8 +444,7 @@ class Table(object):
         return col
 
     def apply_stylesheet(self, stylesheet: "TableStyleSheet") -> None:
-        """Applies the stylesheet to this table
-        """
+        """Applies the stylesheet to this table"""
         for instruction in stylesheet.instructions:
             eval(instruction)
 
@@ -526,8 +513,7 @@ class Table(object):
 
 
 class TableStyle:
-    """Defines a table's style
-    """
+    """Defines a table's style"""
 
     def __init__(self, table: Table) -> None:
 
@@ -546,8 +532,7 @@ class TableStyle:
 
     # XXX FIXME : params order should be reversed for all set() methods
     def set_size(self, value: str, col_id: str) -> None:
-        """sets the size of the specified col_id to value
-        """
+        """sets the size of the specified col_id to value"""
         self.size[col_id] = value
 
     def set_size_by_index(self, value: str, col_index: int) -> None:
@@ -563,8 +548,7 @@ class TableStyle:
         self.size[col_id] = value
 
     def set_alignment(self, value: str, col_id: str) -> None:
-        """sets the alignment of the specified col_id to value
-        """
+        """sets the alignment of the specified col_id to value"""
         self.alignment[col_id] = value
 
     def set_alignment_by_index(self, value: str, col_index: int) -> None:
@@ -580,8 +564,7 @@ class TableStyle:
         self.alignment[col_id] = value
 
     def set_unit(self, value: str, col_id: str) -> None:
-        """sets the unit of the specified col_id to value
-        """
+        """sets the unit of the specified col_id to value"""
         self.units[col_id] = value
 
     def set_unit_by_index(self, value: str, col_index: int) -> None:
@@ -599,8 +582,7 @@ class TableStyle:
         self.units[col_id] = value
 
     def get_size(self, col_id: str) -> str:
-        """Returns the size of the specified col_id
-        """
+        """Returns the size of the specified col_id"""
         return self.size[col_id]
 
     def get_size_by_index(self, col_index: int) -> str:
@@ -616,8 +598,7 @@ class TableStyle:
         return self.size[col_id]
 
     def get_alignment(self, col_id: str) -> str:
-        """Returns the alignment of the specified col_id
-        """
+        """Returns the alignment of the specified col_id"""
         return self.alignment[col_id]
 
     def get_alignment_by_index(self, col_index: int) -> str:
@@ -633,8 +614,7 @@ class TableStyle:
         return self.alignment[col_id]
 
     def get_unit(self, col_id: str) -> str:
-        """Returns the unit of the specified col_id
-        """
+        """Returns the unit of the specified col_id"""
         return self.units[col_id]
 
     def get_unit_by_index(self, col_index: int) -> str:
@@ -678,8 +658,7 @@ class TableStyleSheet:
             self.add_rule(rule)
 
     def add_rule(self, rule: str) -> None:
-        """Adds a rule to the stylesheet rules
-        """
+        """Adds a rule to the stylesheet rules"""
         try:
             source_code = ["from math import *"]
             source_code.append(CELL_PROG.sub(r"self.data[\1][\2]", rule))
@@ -756,8 +735,7 @@ class TableStyleSheet:
 
 
 class TableCellRenderer:
-    """Defines a simple text renderer
-    """
+    """Defines a simple text renderer"""
 
     def __init__(self, **properties: Any) -> None:
         """keywords should be properties with an associated boolean as value.
@@ -772,8 +750,7 @@ class TableCellRenderer:
     def render_cell(
         self, cell_coord: Tuple[int, int], table: Table, table_style: TableStyle
     ) -> Union[str, int]:
-        """Renders the cell at 'cell_coord' in the table, using table_style
-        """
+        """Renders the cell at 'cell_coord' in the table, using table_style"""
         row_index, col_index = cell_coord
         cell_value = table.data[row_index][col_index]
         final_content = self._make_cell_content(cell_value, table_style, col_index + 1)
@@ -782,16 +759,14 @@ class TableCellRenderer:
     def render_row_cell(
         self, row_name: str, table: Table, table_style: TableStyle
     ) -> Union[str, int]:
-        """Renders the cell for 'row_id' row
-        """
+        """Renders the cell for 'row_id' row"""
         cell_value = row_name
         return self._render_cell_content(cell_value, table_style, 0)
 
     def render_col_cell(
         self, col_name: str, table: Table, table_style: TableStyle
     ) -> Union[str, int]:
-        """Renders the cell for 'col_id' row
-        """
+        """Renders the cell for 'col_id' row"""
         cell_value = col_name
         col_index = table.col_names.index(col_name)
         return self._render_cell_content(cell_value, table_style, col_index + 1)
@@ -832,19 +807,16 @@ class TableCellRenderer:
         return final_content
 
     def _add_unit(self, cell_content: int, table_style: TableStyle, col_index: int) -> str:
-        """Adds unit to the cell_content if needed
-        """
+        """Adds unit to the cell_content if needed"""
         unit = table_style.get_unit_by_index(col_index)
         return str(cell_content) + " " + unit
 
 
 class DocbookRenderer(TableCellRenderer):
-    """Defines how to render a cell for a docboook table
-    """
+    """Defines how to render a cell for a docboook table"""
 
     def define_col_header(self, col_index: int, table_style: TableStyle) -> str:
-        """Computes the colspec element according to the style
-        """
+        """Computes the colspec element according to the style"""
         size = table_style.get_size_by_index(col_index)
         return '<colspec colname="c%d" colwidth="%s"/>\n' % (col_index, size)
 
@@ -869,8 +841,7 @@ class DocbookRenderer(TableCellRenderer):
 
 
 class TableWriter:
-    """A class to write tables
-    """
+    """A class to write tables"""
 
     def __init__(
         self, stream: StringIO, table: Table, style: Optional[Any], **properties: Any
@@ -882,33 +853,27 @@ class TableWriter:
         self.renderer: Optional[DocbookRenderer] = None
 
     def set_style(self, style):
-        """sets the table's associated style
-        """
+        """sets the table's associated style"""
         self.style = style
 
     def set_renderer(self, renderer: DocbookRenderer) -> None:
-        """sets the way to render cell
-        """
+        """sets the way to render cell"""
         self.renderer = renderer
 
     def update_properties(self, **properties):
-        """Updates writer's properties (for cell rendering)
-        """
+        """Updates writer's properties (for cell rendering)"""
         self.properties.update(properties)
 
     def write_table(self, title: str = "") -> None:
-        """Writes the table
-        """
+        """Writes the table"""
         raise NotImplementedError("write_table must be implemented !")
 
 
 class DocbookTableWriter(TableWriter):
-    """Defines an implementation of TableWriter to write a table in Docbook
-    """
+    """Defines an implementation of TableWriter to write a table in Docbook"""
 
     def _write_headers(self) -> None:
-        """Writes col headers
-        """
+        """Writes col headers"""
         assert self.renderer is not None
 
         # Define col_headers (colstpec elements)
@@ -924,8 +889,7 @@ class DocbookTableWriter(TableWriter):
         self._stream.write("</row>\n</thead>\n")
 
     def _write_body(self) -> None:
-        """Writes the table body
-        """
+        """Writes the table body"""
         assert self.renderer is not None
 
         self._stream.write("<tbody>\n")
@@ -946,8 +910,7 @@ class DocbookTableWriter(TableWriter):
         self._stream.write("</tbody>\n")
 
     def write_table(self, title: str = "") -> None:
-        """Writes the table
-        """
+        """Writes the table"""
         self._stream.write("<table>\n<title>%s></title>\n" % (title))
         self._stream.write(
             '<tgroup cols="%d" align="left" colsep="1" rowsep="1">\n'
