@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 # copyright 2003-2012 LOGILAB S.A. (Paris, FRANCE), all rights reserved.
 # contact http://www.logilab.fr/ -- mailto:contact@logilab.fr
 #
@@ -37,7 +36,6 @@ If no non-option arguments are present, prefixes used are 'test',
 
 """
 
-from __future__ import print_function
 
 __docformat__ = "restructuredtext en"
 # modified copy of some functions from test/regrtest.py from PyXml
@@ -132,8 +130,7 @@ def with_tempdir(callable: Callable) -> Callable:
 
 
 def in_tempdir(callable):
-    """A decorator moving the enclosed function inside the tempfile.tempfdir
-    """
+    """A decorator moving the enclosed function inside the tempfile.tempfdir"""
 
     @wraps(callable)
     def proxy(*args, **kargs):
@@ -149,8 +146,7 @@ def in_tempdir(callable):
 
 
 def within_tempdir(callable):
-    """A decorator run the enclosed function inside a tmpdir removed after execution
-    """
+    """A decorator run the enclosed function inside a tmpdir removed after execution"""
     proxy = with_tempdir(in_tempdir(callable))
     proxy.__name__ = callable.__name__
     return proxy
@@ -175,8 +171,7 @@ def find_tests(testdir, prefixes=DEFAULT_PREFIXES, suffix=".py", excludes=(), re
 
 # PostMortem Debug facilities #####
 def start_interactive_mode(result):
-    """starts an interactive shell so that the user can inspect errors
-    """
+    """starts an interactive shell so that the user can inspect errors"""
     debuggers = result.debuggers
     descrs = result.error_descrs + result.fail_descrs
     if len(debuggers) == 1:
@@ -722,7 +717,7 @@ def tag(*args: str, **kwargs: Any) -> Callable:
 
 
 def require_version(version: str) -> Callable:
-    """ Compare version of python interpreter to the given one. Skip the test
+    """Compare version of python interpreter to the given one. Skip the test
     if older.
     """
 
@@ -750,8 +745,7 @@ def require_version(version: str) -> Callable:
 
 
 def require_module(module: str) -> Callable:
-    """ Check if the given module is loaded. Skip the test if not.
-    """
+    """Check if the given module is loaded. Skip the test if not."""
 
     def check_require_module(f: Callable) -> Callable:
         try:
